translate.misc.typecheck._TC_YieldCountError

Package translate :: Package misc :: Package typecheck :: Class _TC_YieldCountError |
[hide private]
[frames] | no frames]

# Class _TC_YieldCountError

source code

Instance Methods | [hide private]
__init__(self, expected) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
format_bad_object(self, bad_object) | source code
error_message(self) | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, expected) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### format_bad_object(self, bad_object) | source code
Overrides: _TC_Exception.format_bad_object

### error_message(self) | source code
Overrides: _TC_Exception.error_message